@@ -4,8 +4,6 @@ def theme(req, theme='default'):
     print("SETTING THEME TO %s" % theme)
 
     ref = req.META.get('HTTP_REFERER', '/')
-    if not ref:
-        ref = '/'    
 
     req.session['bootstrap_theme'] = theme
     print("THEME: %s" % theme)
